"use client";
import Image from "next/image";

import { MapPin } from "lucide-react";

import { ImageBaseUrl } from "@/configs/api";
import { cn } from "@/lib/utils";
import { useUserInfo } from "@/servers/data/use-userinfo";
import { Icon } from "@iconify/react/dist/iconify.js";
import { useLocale } from "next-intl";
import { useState } from "react";

const AccountInformation = ({ setImageFile }: { setImageFile: (file: File) => void }) => {
	const { userInfo } = useUserInfo();

	const locale = useLocale();
	const [selectedImage, setSelectedImage] = useState<string | null>(null);

	const handleImageChange = (event: React.ChangeEvent<HTMLInputElement>) => {
		const file = event.target.files?.[0];
		if (file) {
			setImageFile(file);
			const reader = new FileReader();
			reader.onloadend = () => {
				setSelectedImage(reader.result as string);
			};
			reader.readAsDataURL(file);
		}
	};

	return (

		<div
			className={"mt-12 flex h-fit flex-row items-stretch justify-between md:flex"}
		>
			<div className="flex items-stretch">
				<div className="mx-4 flex w-full max-w-72 flex-col md:mx-2 lg:mx-4 xl:mx-11">
					<p className={cn("text-lg text-custom-fourth", locale === "ar" ? "text-left" : "text-right")}>{userInfo?.first_name} {userInfo?.last_name}</p>
					<div className="flex w-full justify-end gap-2 mt-2">
						<div className="flex gap-2">
							<p className={cn("text-sm text-custom-fifth", locale === "ar" ? "text-left" : "text-right")}>{userInfo?.address}</p>
							{userInfo?.address && <MapPin color="#3D475C" size={"16px"} />}
						</div>
					</div>
				</div>
			</div>
			<div className="">
				<Image
					src={selectedImage || (userInfo?.image ? ImageBaseUrl + userInfo?.image : "/images/profile/user-profile.jpg")}
					width={190}
					height={190}
					alt="user image"
					style={{ width: "190px", height: "190px", borderRadius: "50%" }}
					className="relative z-50 -mt-[77px] object-cover"
				/>
				<input
					type="file"
					accept="image/*"
					onChange={handleImageChange}
					className="hidden"
					id="imageUpload"
				/>
				<label htmlFor="imageUpload" className="flex h-9 w-9 items-center justify-center rounded-full relative z-50 -mt-[48px] bg-green-700 transition-all duration-100 hover:scale-105 cursor-pointer">
					<Icon icon="solar:camera-broken" className="text-white font-bold w-5 h-5" />
				</label>
			</div>
		</div>
	);
};

export default AccountInformation;
